IPCweights: Inverse Probability of Censoring Weights

View source: R/survival.R

IPCweightsR Documentation

Inverse Probability of Censoring Weights

Description

Compute weights for censored regression via the inverted probability of censoring principle.

Usage

IPCweights(x, maxweight = 5)

Arguments

x

an object of class Surv.

maxweight

the maximal value of the returned weights.

Details

Inverse probability of censoring weights are one possibility to fit models formulated in the full data world in the presence of censoring, i.e., the observed data world \bibcitepmboost::Laan_Robins_2003, see \bibcitetmboost::Hothorn:2006:Biostatistics:16344280 for an application to survival analysis.

Value

A vector of numeric weights.

References

\bibshow

*


mboost documentation built on July 15, 2026, 5:06 p.m.