| IPCweights | R Documentation |
Compute weights for censored regression via the inverted probability of censoring principle.
IPCweights(x, maxweight = 5)
x |
an object of class |
maxweight |
the maximal value of the returned weights. |
Inverse probability of censoring weights are one possibility to fit models formulated in the full data world in the presence of censoring, i.e., the observed data world \bibcitepmboost::Laan_Robins_2003, see \bibcitetmboost::Hothorn:2006:Biostatistics:16344280 for an application to survival analysis.
A vector of numeric weights.
*
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.