Learn R Programming

mboost (version 2.9-13)

IPCweights: Inverse Probability of Censoring Weights

Description

Compute weights for censored regression via the inverted probability of censoring principle.

Usage

IPCweights(x, maxweight = 5)

Value

A vector of numeric weights.

Arguments

x

an object of class Surv.

maxweight

the maximal value of the returned weights.

Details

Inverse probability of censoring weights are one possibility to fit models formulated in the full data world in the presence of censoring, i.e., the observed data world mboost::Laan_Robins_2003, see mboost::Hothorn:2006:Biostatistics:16344280 for an application to survival analysis.

References

*