Compute weights for censored regression via the inverted probability of censoring principle.
IPCweights(x, maxweight = 5)A vector of numeric weights.
an object of class Surv.
the maximal value of the returned weights.
Inverse probability of censoring weights are one possibility to fit models formulated in the full data world in the presence of censoring, i.e., the observed data world mboost::Laan_Robins_2003, see mboost::Hothorn:2006:Biostatistics:16344280 for an application to survival analysis.
*