The function implements component-wise functional gradient boosting in
a generic way. This function is the main work horse and used as back-end by
all boosting algorithms in a unified way. Usually, this function is not
called directly. Note that the more convenient modelling interfaces
gamboost, glmboost and blackboost
all call mboost_fit.
Basically, the algorithm is initialized with a function
for computing the negative gradient of the loss function (via its
family argument) and one or more base-learners (given as
blg). Usually blg and response are computed in
the functions gamboost, glmboost,
blackboost or mboost. See there for details
on the specification of base-learners.
The algorithm minimized the in-sample empirical risk defined as
the weighted sum (by weights) of the loss function (corresponding
to the negative gradient) evaluated at the data.
The structure of the model is determined by the structure
of the base-learners. If more than one base-learner is given,
the model is additive in these components.
Base-learners can be specified via a formula interface
(function mboost) or as a list of objects of class bl,
see, e.g., bols.
oobweights is a vector used internally by cvrisk. When carrying
out cross-validation to determine the optimal stopping iteration of a boosting
model, the default value of oobweights (out-of-bag weights) assures
that the cross-validated risk is computed using the same observation weights
as those used for fitting the boosting model. It is strongly recommended to
leave this argument unspecified.